@@ -1,6 +1,5 @@
 import numpy as np
 import os
-from paddleocr import PaddleOCR
 from statistics import mode
 import time
 import re
@@ -8,7 +7,7 @@ import cv2
 from getmac import get_mac_address as gma
 
 
-def inference(img_path,lang,model_rec,model_det):
+def inference(img_path,ocr):
     try:
         macadd=gma()
         uniqueadd =["60:e3:2b:34:66:ce","a8:7e:ea:41:ad:34","1c:69:7a:ae:44:32"]
